const os = require('os');
const rimraf = require('rimraf');
const { assert } = require('chai');

const { dirExists, listExists, getAndParseWords } = require('../src/fs-helpers');
const { newList } = require('../src/new');
const { addWord } = require('../src/add');

const home = os.homedir();
const route = `${home}\\.my-own-words`;

const listName = 'italian';
const word = 'Ciao';
const firstDef = 'Hi';
const secondDef = 'Goodbye';

describe('Before #add', () => {
  before(() => {
    rimraf.sync(route);
  });

  it('should delete the test directory', () => {
    assert.isFalse(dirExists());
  });

  it(`should create a clear test directory with an empty list called ${listName}`, () => {
    newList(listName);

    assert.isTrue(dirExists());
    assert.isTrue(listExists(listName));
    assert.isObject(getAndParseWords(listName));
  });
});

describe('#addWord', () => {
  it(`should add "${word}" word into the ${listName} list`, () => {
    addWord(listName, word, firstDef);

    assert.property(getAndParseWords(listName), `${word}`);
  });

  it(`should add a new defintion if the "${word}" word already exists into the ${listName} list`, () => {
    addWord(listName, word, secondDef);

    assert.include(getAndParseWords(listName)[word], secondDef);
  });

  it(`shouldn't add a repeated definition to the definitions array of ${word}`, () => {
    assert.lengthOf(getAndParseWords(listName)[word], 2);
    assert.strictEqual(getAndParseWords(listName)[word][0], firstDef);
    assert.strictEqual(getAndParseWords(listName)[word][1], secondDef);
  });
});
