const os = require('os');
const rimraf = require('rimraf');
const { assert } = require('chai');

const { dirExists, listExists, getAndParseWords } = require('../src/fs-helpers');
const { newList } = require('../src/new');

const home = os.homedir();
const route = `${home}\\.my-own-words`;

const listName = 'italian';

describe('Before #newList', () => {
  before(() => {
    rimraf.sync(route);
  });

  it('should delete the test directory', () => {
    assert.isFalse(dirExists());
  });
});

describe('#newList', () => {
  it('should make a directory if that not exists', () => {
    newList(listName);

    assert.isTrue(dirExists());
  });

  it(`should create a list called ${listName} if that not exists`, () => {
    assert.isTrue(listExists(listName));
  });

  it(`should return a message if the list ${listName} already exists`, () => {
    assert.strictEqual(newList(listName), `${listName} list already exists!`);
  });

  it(`list ${listName} should contain an empty object at first`, () => {
    assert.isObject(getAndParseWords(listName));
  });
});
