const os = require('os');
const rimraf = require('rimraf');
const { assert } = require('chai');

const { dirExists, listExists, getAndParseWords } = require('../src/fs-helpers');
const { newList } = require('../src/new');
const { addWord } = require('../src/add');
const { remove } = require('../src/remove');

const home = os.homedir();
const route = `${home}\\.my-own-words`;

const listName = 'italian';
const altListName = 'japanese';
const word = 'Ciao';
const secondWord = 'Arrivederci';
const firstDef = 'Hi';
const secondDef = 'Goodbye';

describe('Before #remove', () => {
  before(() => {
    rimraf.sync(route);
  });

  it('should delete the test directory', () => {
    assert.isFalse(dirExists());
  });

  it(`should create a clear test directory with an empty list called ${listName}`, () => {
    newList(listName);
    assert.isTrue(dirExists());
    assert.isTrue(listExists(listName));
    assert.isObject(getAndParseWords(listName));
  });

  it('test list should have a word with two definitions', () => {
    addWord(listName, word, firstDef);
    addWord(listName, word, secondDef);
    addWord(listName, secondWord, secondDef);

    assert.property(getAndParseWords(listName), `${word}`);
    assert.include(getAndParseWords(listName)[word], secondDef);
    assert.property(getAndParseWords(listName), `${secondWord}`);
  });
});

describe('#remove', () => {
  it('should return a message if the specified list does not exist', () => {
    assert.toString(remove(altListName, word, firstDef));
    assert.strictEqual(remove(altListName, word, firstDef), `${altListName} list doesn't exists!`);
  });

  it('should delete a list if that is the only parameter specified', () => {
    newList(altListName);

    assert.isTrue(listExists(altListName));

    remove(altListName, undefined, undefined);

    assert.isFalse(listExists(altListName));
  });

  it('should delete a word correctly', () => {
    remove(listName, secondWord, undefined);

    assert.notExists(getAndParseWords(listName)[secondWord]);
  });

  it("should delete a word's defintion correctly", () => {
    remove(listName, word, secondDef);

    assert.include(getAndParseWords(listName)[word], firstDef);
    assert.notInclude(getAndParseWords(listName)[word], secondDef);
  });
});
